/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fulltext.impl;

import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.apache.lucene.document.Field;

/**
 * 索引结果集
 * 
 * @author renhui
 * 
 */
public class ResultSetIndexProcessor extends AbstractIndexProcessor<ResultSet> {

	public String getId(ResultSet indexObject) {
		try {
			ResultSetMetaData metaData = indexObject.getMetaData();
			return metaData.getTableName(1);
		} catch (SQLException e) {
			getLogger().error(e);
		}
		return null;
	}

	public String getContents(ResultSet indexObject) {
		StringBuilder builder = new StringBuilder();
		try {
			ResultSetMetaData metaData = indexObject.getMetaData();
			indexObject.beforeFirst();
			while (indexObject.next()) {
				for (int columnIndex = 1; columnIndex <= metaData
						.getColumnCount(); columnIndex++) {
					Object data = null;
					int type = metaData.getColumnType(columnIndex);
					if (type == java.sql.Types.BLOB) {
						java.sql.Blob blob = indexObject.getBlob(columnIndex);
						if (blob != null) {
							data = blob.getBytes(1, (int) blob.length());
						}
					} else if (type == java.sql.Types.LONGVARBINARY
							|| type == java.sql.Types.VARBINARY
							|| type == java.sql.Types.BINARY) {
						data = indexObject.getBytes(columnIndex);
					} else {
						data = indexObject.getObject(columnIndex);
					}
					builder.append(data.toString()).append(" ");
				}
				builder.append("\r\n");
			}
		} catch (SQLException e) {
			getLogger().error(e);
		}
		return builder.toString();
	}

	public List<Field> getExternFieldList(ResultSet indexObject) {
		return new ArrayList<Field>();
	}

}
